azureconfig

package
v1.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2025 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	// EnvAzurePrefix is the prefix applied to every azure
	// environment variable For example, for a prefix of "DEV_AZURE_", the
	// variables would be "DEV_AZURE_TENANT_ID", "DEV_AZURE_CLIENT_ID",
	// "DEV_AZURE_CLIENT_SECRET". By default the prefix is "AZURE_".
	EnvAzurePrefix string `json:"env-azure-prefix"`

	// Vault is the name of the vault containing bundle secrets.
	Vault string `json:"vault"`
	// VaultUrl is the full url of the vault containing bundle secrets.
	VaultUrl string `json:"vault-url"`
}

Jump to